/* 
 Debounce
 Nyomógomb megnyomásával tudjuk be-, majd újbóli megnyomásával  kikapcsolni a LED fényét.
 
 Áramkör:
 * LED a 13 pinbe és a földbe kötve (beépített LED)
 * nyomógomb 2 pinből az 5 V-ba megy
 * 10 kiloohmos ellenállás a 2 pinből
 
 created 21 November 2006 by David A. Mellis
 modified 30 Aug 2011 by Limor Fried
 */

// állandókkal megadjuk a pin értékeket:
const int buttonPin = 2;     // nyomógomb pin
const int ledPin =  13;      // LED pin

// változókat hozunk létre:
int ledState = HIGH;   // kimeneti pin aktuális állapota
int buttonState;   // bemeneti pin aktuális állapota 
int lastButtonState = LOW;   // bemeneti pin előző értéke

/* a következő változók long típusúak lesznek, mivel az időt milliszekundumban mérjük, ezért értéke gyorsan nagyra nő, akkorára, amit integerben nem tudunk tárolni */

long lastDebounceTime = 0;  
// a kimeneti pin átkapcsolásának utolsó időértéke 
long debounceDelay = 50;    
// késleltetési idő; ha a kimenet vibrál, meg kell növelni

void setup() {
  pinMode(buttonPin, INPUT);
  pinMode(ledPin, OUTPUT);

  // adjuk meg a LED állapotának kezdő értékét
  digitalWrite(ledPin, ledState);
}

void loop() {
  // helyi változóba kiolvassuk a kapcsoló állapotát:
  int reading = digitalRead(buttonPin);

  // leellenőrizzük, hogy elég idő telt-e el a két kiolvasás között:

  // Ellenőrizzük, hogy megnyomás vagy zaj 
  // hatására változott-e a kapcsoló:
  if (reading != lastButtonState) {
    // a késleltetés időzítőt újraindítjuk:
    lastDebounceTime = millis();
  } 

  if ((millis() - lastDebounceTime) > debounceDelay) {
    /* ha az eltelt időből kivonjuk az utolsó átkapcsolás idejét, és az nagyobb, mint a késleltetési idő, akkor – mivel ez gombnyomásra utal – a reading nevű integer változóban eltárolt adatunkat hozzárendeljük a nyomógomb aktuális értékét tároló változónkhoz */

    // ha a nyomógomb állapota megváltozik:
    if (reading != buttonState) {
      buttonState = reading;

      // ha a nyomógomb állapota HIGH, benyomott, akkor
      // átkapcsoljuk a LED állapotát az aktuális ellenkezőjére
      if (buttonState == HIGH) {
        ledState = !ledState;
      }
    }
  }

  // és ezzel az értékkel beállítjuk a  LED állapotát:
  digitalWrite(ledPin, buttonState);

  // majd elmentjük. A loop következő lefutásánál már 
  // ez lesz a kezdő értéke ennek a változónak  
  lastButtonState = reading;
}



